pub struct GetIntentResponse {
pub intent: Option<Intent>,
pub intents: Option<Vec<Intent>>,
}Expand description
GetIntentResponse : The repeated intents field is always populated with the matching results. The singular intent field is only set for backward compatibility when the request uses the txid filter, in which case it mirrors intents[0].
Fields
intent: Option<Intent>intents: Option<Vec<Intent>>Implementations
Sourceimpl GetIntentResponse
impl GetIntentResponse
Sourcepub fn new() -> GetIntentResponse
pub fn new() -> GetIntentResponse
The repeated intents field is always populated with the matching results. The singular intent field is only set for backward compatibility when the request uses the txid filter, in which case it mirrors intents[0].