pub struct GetVtxosRequest {
pub after: Option<String>,
pub before: Option<String>,
pub outpoints: Option<Vec<String>>,
pub page: Option<IndexerPageRequest>,
pub pending_only: Option<bool>,
pub recoverable_only: Option<bool>,
pub scripts: Option<Vec<String>>,
pub spendable_only: Option<bool>,
pub spent_only: Option<bool>,
}Fields
after: Option<String>Include only vtxos with last update after the given unix time in milliseconds. A value of 0 means no lower bound.
before: Option<String>Include only vtxos with last update before the given unix time in milliseconds, greater value than the after when specified. A value of 0 means no upper bound.
outpoints: Option<Vec<String>>Or specify a list of vtxo outpoints. The 2 filters are mutually exclusive.
page: Option<IndexerPageRequest>pending_only: Option<bool>Include only spent vtxos that are not finalized.
recoverable_only: Option<bool>Retrieve only recoverable vtxos (notes, subdust or swept vtxos). The 3 filters are mutually exclusive,
scripts: Option<Vec<String>>Either specify a list of vtxo scripts.
spendable_only: Option<bool>Retrieve only spendable vtxos
spent_only: Option<bool>Retrieve only spent vtxos.
Implementations
Sourceimpl GetVtxosRequest
impl GetVtxosRequest
pub fn new() -> GetVtxosRequest