pub struct UpdateStreamTopicsRequest {
pub modify: Option<ModifyTopics>,
pub overwrite: Option<OverwriteTopics>,
pub stream_id: Option<String>,
}Expand description
UpdateStreamTopicsRequest : Adding and removing topics can both be supplied in the same request, allowing for simultaneous changes. overwrite_topics will take precedence, and if set, then the add/remove topics are ignored. The stream_id is required.
Fields
modify: Option<ModifyTopics>overwrite: Option<OverwriteTopics>stream_id: Option<String>Implementations
Sourceimpl UpdateStreamTopicsRequest
impl UpdateStreamTopicsRequest
Sourcepub fn new() -> UpdateStreamTopicsRequest
pub fn new() -> UpdateStreamTopicsRequest
Adding and removing topics can both be supplied in the same request, allowing for simultaneous changes. overwrite_topics will take precedence, and if set, then the add/remove topics are ignored. The stream_id is required.