pub struct WithdrawRequest {
pub address: Option<String>,
pub all: Option<bool>,
pub amount: Option<String>,
}Fields
address: Option<String>all: Option<bool>if all=true, amount is ignored and all available balance is withdrawn including connectors account funds must be used carefully to not make connectors utxos unspendable, making forfeit txs invalid
amount: Option<String>Implementations
Sourceimpl WithdrawRequest
impl WithdrawRequest
pub fn new() -> WithdrawRequest