pub struct Error { /* private fields */ }Implementations
Sourceimpl Error
impl Error
Sourcepub fn is_server_info_changed(&self) -> bool
pub fn is_server_info_changed(&self) -> bool
Returns true if the failed operation triggered a digest-mismatch refresh of the
cached /info. The original request was not retried.
Sourcepub fn is_version_mismatch(&self) -> bool
pub fn is_version_mismatch(&self) -> bool
Returns true if the server rejected the request because the SDK
version is too old.