pub struct DeleteIntentRequest {
pub intent: Option<Intent>,
}Fields
intent: Option<Intent>an intent proof that includes any of the inputs of the intent to be deleted to prove the ownership of that intent.
Implementations
Sourceimpl DeleteIntentRequest
impl DeleteIntentRequest
pub fn new() -> DeleteIntentRequest